Struct slint_build::CompilerConfiguration
source · pub struct CompilerConfiguration { /* private fields */ }Expand description
The structure for configuring aspects of the compilation of .slint markup files to Rust.
Implementations
sourceimpl CompilerConfiguration
impl CompilerConfiguration
sourcepub fn with_include_paths(self, include_paths: Vec<PathBuf>) -> Self
pub fn with_include_paths(self, include_paths: Vec<PathBuf>) -> Self
Create a new configuration that includes sets the include paths used for looking up
.slint imports to the specified vector of paths.
sourcepub fn with_style(self, style: String) -> Self
pub fn with_style(self, style: String) -> Self
Create a new configuration that selects the style to be used for widgets.
sourcepub fn embed_resources(self, kind: EmbedResourcesKind) -> Self
pub fn embed_resources(self, kind: EmbedResourcesKind) -> Self
Selects how the resources such as images and font are processed.